==> binnie-mods-1.11.2-2.1.0.31-sources.jar: binnie/botany/items/ItemClay.java <==
package binnie.botany.items;

import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.NonNullList;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.core.IItemModelRegister;
import forestry.api.core.IModelManager;
import forestry.core.items.IColoredItem;

import binnie.botany.CreativeTabBotany;
import binnie.botany.genetics.EnumFlowerColor;
import binnie.core.util.I18N;

public class ItemClay extends Item implements IColoredItem, IItemModelRegister {
	public ItemClay() {
		func_77655_b("botany.clay");
		func_77627_a(true);
		func_77637_a(CreativeTabBotany.instance);
		setRegistryName("clay");
	}

	@SideOnly(Side.CLIENT)
	@Override
	public void registerModel(Item item, IModelManager manager) {
		for (EnumFlowerColor color : EnumFlowerColor.values()) {
			manager.registerItemModel(item, color.ordinal());
		}
	}

	@SideOnly(Side.CLIENT)
	@Override
	public int getColorFromItemstack(ItemStack stack, int tintIndex) {
		EnumFlowerColor color = EnumFlowerColor.get(stack.func_77952_i());
		return color.getFlowerColorAllele().getColor(false);
	}

	@Override
	public String func_77653_i(ItemStack stack) {
		EnumFlowerColor color = EnumFlowerColor.get(stack.func_77952_i());
		return I18N.localise("item.botany.clay.name", color.getFlowerColorAllele().getColorName());
	}

	@Override
	@SideOnly(Side.CLIENT)
	public void func_150895_a(Item itemIn, CreativeTabs tab, NonNullList<ItemStack> list) {
		for (EnumFlowerColor color : EnumFlowerColor.values()) {
			list.add(new ItemStack(this, 1, color.ordinal()));
		}
	}
}

==> binnie-mods-1.11.2-2.1.0.41-sources.jar: binnie/botany/items/ItemClay.java <==
package binnie.botany.items;

import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.NonNullList;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.core.IItemModelRegister;
import forestry.api.core.IModelManager;
import forestry.core.items.IColoredItem;

import binnie.botany.genetics.EnumFlowerColor;
import binnie.core.util.I18N;

public class ItemClay extends ItemBotany implements IColoredItem, IItemModelRegister {
	public ItemClay() {
		super("clay");
		func_77655_b("botany.clay");
		func_77627_a(true);
	}

	@SideOnly(Side.CLIENT)
	@Override
	public void registerModel(Item item, IModelManager manager) {
		for (EnumFlowerColor color : EnumFlowerColor.values()) {
			manager.registerItemModel(item, color.ordinal());
		}
	}

	@SideOnly(Side.CLIENT)
	@Override
	public int getColorFromItemstack(ItemStack stack, int tintIndex) {
		EnumFlowerColor color = EnumFlowerColor.get(stack.func_77952_i());
		return color.getFlowerColorAllele().getColor(false);
	}

	@Override
	public String func_77653_i(ItemStack stack) {
		EnumFlowerColor color = EnumFlowerColor.get(stack.func_77952_i());
		return I18N.localise("item.botany.clay.name", color.getFlowerColorAllele().getColorName());
	}

	@Override
	@SideOnly(Side.CLIENT)
	public void func_150895_a(Item itemIn, CreativeTabs tab, NonNullList<ItemStack> list) {
		for (EnumFlowerColor color : EnumFlowerColor.values()) {
			list.add(new ItemStack(this, 1, color.ordinal()));
		}
	}
}
